@@ -1,10 +1,12 @@
 #include "KinoSearch/Util/ToolSet.h"
 
 #include "KinoSearch/Index/SortReader.h"
+#include "KinoSearch/FieldType.h"
 #include "KinoSearch/Schema.h"
 #include "KinoSearch/Index/Segment.h"
 #include "KinoSearch/Index/Snapshot.h"
-#include "KinoSearch/Index/SortCache.h"
+#include "KinoSearch/Index/SortCache/NumericSortCache.h"
+#include "KinoSearch/Index/SortCache/TextSortCache.h"
 #include "KinoSearch/Index/SortWriter.h"
 #include "KinoSearch/Store/Folder.h"
 #include "KinoSearch/Util/I32Array.h"
@@ -68,9 +70,18 @@ DefSortReader_init(DefaultSortReader *self, Schema *schema, Folder *folder,
     if (metadata) {
         self->counts = (Hash*)INCREF(ASSERT_IS_A(
             Hash_Fetch_Str(metadata, "counts", 6), HASH));
+        self->null_ords = (Hash*)Hash_Fetch_Str(metadata, "null_ords", 9);
+        if (self->null_ords) {
+            ASSERT_IS_A(self->null_ords, HASH);
+            INCREF(self->null_ords);
+        }
+        else {
+            self->null_ords = Hash_new(0);
+        }
     }
     else {
-        self->counts = Hash_new(0);
+        self->counts    = Hash_new(0);
+        self->null_ords = Hash_new(0);
     }
 
     return self;
@@ -87,6 +98,10 @@ DefSortReader_close(DefaultSortReader *self)
         Hash_Dec_RefCount(self->counts);
         self->counts = NULL;
     }
+    if (self->null_ords) {
+        Hash_Dec_RefCount(self->null_ords);
+        self->null_ords = NULL;
+    }
 }
 
 void
@@ -94,6 +109,7 @@ DefSortReader_destroy(DefaultSortReader *self)
 {
     DECREF(self->caches);
     DECREF(self->counts);
+    DECREF(self->null_ords);
     SUPER_DESTROY(self, DEFAULTSORTREADER);
 }
 
@@ -103,15 +119,45 @@ DefSortReader_fetch_sort_cache(DefaultSortReader *self, const CharBuf *field)
     SortCache *cache = NULL;
 
     if (field) {
-        cache = (SortCache*)Hash_Fetch(self->caches, field);
+        cache = (SortCache*)Hash_Fetch(self->caches, (Obj*)field);
         if (!cache) {
-            if (Hash_Fetch(self->counts, field)) {
-                Schema  *schema    = DefSortReader_Get_Schema(self);
-                Folder  *folder    = DefSortReader_Get_Folder(self);
-                Segment *segment   = DefSortReader_Get_Segment(self);
-                i32_t    field_num = Seg_Field_Num(segment, field);
-                cache = SortCache_new(schema, folder, segment, field_num);
-                Hash_Store(self->caches, field, (Obj*)cache);
+            Obj *count = Hash_Fetch(self->counts, (Obj*)field);
+            if (count) {
+                Schema    *schema    = DefSortReader_Get_Schema(self);
+                Folder    *folder    = DefSortReader_Get_Folder(self);
+                Segment   *segment   = DefSortReader_Get_Segment(self);
+                i32_t      field_num = Seg_Field_Num(segment, field);
+                FieldType *type      = Schema_Fetch_Type(schema, field);
+                i8_t       prim_id   = FType_Primitive_ID(type);
+                Obj *null_ord_obj 
+                    = Hash_Fetch(self->null_ords, (Obj*)field);
+                i32_t null_ord = null_ord_obj 
+                               ?  (i64_t)Obj_To_I64(null_ord_obj) : -1;
+                switch (prim_id & FType_PRIMITIVE_ID_MASK) {
+                    case FType_TEXT:
+                        cache = (SortCache*)TextSortCache_new(schema, folder,
+                            segment, field_num, Obj_To_I64(count), null_ord);
+                        break;
+                    case FType_INT32:
+                        cache = (SortCache*)I32SortCache_new(schema, folder,
+                            segment, field_num, Obj_To_I64(count), null_ord);
+                        break;
+                    case FType_INT64:
+                        cache = (SortCache*)I64SortCache_new(schema, folder,
+                            segment, field_num, Obj_To_I64(count), null_ord);
+                        break;
+                    case FType_FLOAT32:
+                        cache = (SortCache*)F32SortCache_new(schema, folder,
+                            segment, field_num, Obj_To_I64(count), null_ord);
+                        break;
+                    case FType_FLOAT64:
+                        cache = (SortCache*)F64SortCache_new(schema, folder,
+                            segment, field_num, Obj_To_I64(count), null_ord);
+                        break;
+                    default:
+                        THROW("No SortCache class for %o", type);
+                }
+                Hash_Store(self->caches, (Obj*)field, (Obj*)cache);
             }
         }
     }
