@@ -57,19 +57,19 @@ sub build_file_list {
 # Print out stats for one run.
 sub print_interim_report {
     my ( $self, %args ) = @_;
-    printf( "%-3d  Secs: %.2f  Docs: %-4d\n", @args{qw( rep secs count )} );
+    printf( "%-3d  Secs: %.3f  Docs: %-4d\n", @args{qw( rep secs count )} );
 }
 
 sub start_report {
-    # start the output
+    # Start the output.
     print '-' x 60 . "\n";
 }
 
-# Print out aggregate stats
+# Print out aggregate stats.
 sub print_final_report {
     my ( $self, $times ) = @_;
 
-    # produce mean and truncated mean
+    # Produce mean and truncated mean.
     my @sorted_times = sort @$times;
     my $num_to_chop  = int( @sorted_times >> 2 );
     my $mean         = 0;
@@ -77,7 +77,7 @@ sub print_final_report {
     my $num_kept     = 0;
     for ( my $i = 0; $i < @sorted_times; $i++ ) {
         $mean += $sorted_times[$i];
-        # discard fastest 25% and slowest 25% of runs
+        # Discard fastest 25% and slowest 25% of runs.
         next if $i < $num_to_chop;
         next if $i > ( $#sorted_times - $num_to_chop );
         $trunc_mean += $sorted_times[$i];
@@ -87,10 +87,10 @@ sub print_final_report {
     $mean       /= @sorted_times;
     $trunc_mean /= $num_kept;
     my $num_discarded = @sorted_times - $num_kept;
-    $mean       = sprintf( "%.2f", $mean );
-    $trunc_mean = sprintf( "%.2f", $trunc_mean );
+    $mean       = sprintf( "%.3f", $mean );
+    $trunc_mean = sprintf( "%.3f", $trunc_mean );
 
-    # get some info about the system
+    # Get some info about the system.
     my $thread_support = $Config{usethreads} ? "yes" : "no";
     my @uname_info = (uname)[ 0, 2, 4 ];
 
@@ -106,24 +106,22 @@ Truncated mean ($num_kept kept, $num_discarded discarded): $trunc_mean secs
 END_REPORT
 }
 
-package BenchSchema::unstored;
-use base qw( KinoSearch::FieldSpec::text );
+package BenchSchema::WhiteSpaceTokenizer;
+use base qw( KinoSearch::Analysis::Tokenizer );
 
-sub vectorized {0}
-sub stored     {0}
-
-package BenchSchema::unvectorized;
-use base qw( KinoSearch::FieldSpec::text );
-
-sub vectorized {0}
+sub new { return shift->SUPER::new( pattern => '\S+' ) }
 
 package BenchSchema;
 use base qw( KinoSearch::Schema );
 use KinoSearch::Analysis::Tokenizer;
 
-our %fields = ( title => 'BenchSchema::unvectorized' );
-
-sub analyzer { KinoSearch::Analysis::Tokenizer->new( token_re => qr/\S+/ ) }
+sub new {
+    my $self         = shift->SUPER::new;
+    my $type = KinoSearch::FieldType::FullTextType->new(
+        analyzer => BenchSchema::WhiteSpaceTokenizer->new, );
+    $self->spec_field( name => 'title', type => $type );
+    return $self;
+}
 
 package BenchmarkingIndexer::KinoSearch;
 use base qw( BenchmarkingIndexer );
@@ -135,17 +133,16 @@ sub new {
     my $self  = $class->SUPER::new(@_);
 
     require KinoSearch;
-    require KinoSearch::InvIndexer;
-    require KinoSearch::Analysis::TokenBatch;
+    require KinoSearch::Indexer;
 
-    # provide runtime flexibility
+    # Provide runtime flexibility.
     my $schema = $self->{schema} = BenchSchema->new;
-    if ( $self->{store} ) {
-        $schema->add_field( body => 'text' );
-    }
-    else {
-        $schema->add_field( body => 'BenchSchema::unstored' );
-    }
+    my $body_type = KinoSearch::FieldType::FullTextType->new(
+        analyzer      => BenchSchema::WhiteSpaceTokenizer->new,
+        highlightable => $self->{store} ? 1 : 0,
+        stored        => $self->{store} ? 1 : 0,
+    );
+    $schema->spec_field( name => 'body', type => $body_type );
 
     $self->{index_dir} = 'kinosearch_index';
     $self->{engine}    = 'KinoSearch';
@@ -156,16 +153,12 @@ sub new {
 
 sub init_indexer {
     my ( $self, $count ) = @_;
-
-    my $invindex;
-    if ( $count == 0 ) {
-        $invindex = $self->{schema}->clobber( $self->{index_dir} );
-    }
-    else {
-        $invindex = $self->{schema}->open( $self->{index_dir} );
-    }
-
-    return KinoSearch::InvIndexer->new( invindex => $invindex );
+    my $constructor = $count == 0 ? 'clobber' : 'open';
+    return KinoSearch::Indexer->$constructor(
+        schema => $self->{schema},
+        index  => $self->{index_dir},
+        create => 1,
+    );
 }
 
 # Build an index, stopping at $max docs if $max > 0.
@@ -175,15 +168,15 @@ sub build_index {
     my ( $max, $increment, $article_filepaths )
         = @{$self}{qw( docs increment article_filepaths )};
 
-    # start timer
+    # Start timer.
     my $start = gettimeofday();
 
-    my $invindexer = $self->init_indexer(0);
+    my $indexer = $self->init_indexer(0);
 
     my $count = 0;
     while ( $count < $max ) {
         for my $article_filepath (@$article_filepaths) {
-            # the title is the first line, the body is the rest
+            # The title is the first line, the body is the rest.
             open( my $article_fh, '<', $article_filepath )
                 or die "Can't open file '$article_filepath'";
 
@@ -191,23 +184,24 @@ sub build_index {
             $doc{title} = <$article_fh>;
             $doc{body} = do { local $/; <$article_fh> };
 
-            $invindexer->add_doc( \%doc );
+            $indexer->add_doc( \%doc );
 
-            # bail if we've reached spec'd number of docs
+            # Bail if we've reached spec'd number of docs.
             $count++;
             last if $count >= $max;
             if ( $count % $increment == 0 and $count ) {
-                $invindexer->finish;
-                undef $invindexer;
-                $invindexer = $self->init_indexer($count);
+                $indexer->commit;
+                undef $indexer;
+                $indexer = $self->init_indexer($count);
             }
         }
     }
 
-    # finish index
-    $invindexer->finish( optimize => 1 );
+    # Finish index.
+    $indexer->optimize;
+    $indexer->commit;
 
-    # return elapsed seconds
+    # Return elapsed seconds.
     my $end  = gettimeofday();
     my $secs = $end - $start;
     return ( $count, $secs );
@@ -251,10 +245,10 @@ sub build_index {
     my ( $max, $increment, $article_filepaths )
         = @{$self}{qw( docs increment article_filepaths )};
 
-    # cause text to be stored if spec'd
+    # Cause text to be stored if spec'd.
     my $field_constructor = $self->{store} ? 'Text' : 'UnStored';
 
-    # start timer
+    # Start timer.
     my $start = gettimeofday();
 
     my $writer = $self->init_indexer(0);
@@ -262,13 +256,13 @@ sub build_index {
     my $count = 0;
     while ( $count < $max ) {
         for my $article_filepath (@$article_filepaths) {
-            # the title is the first line, the body is the rest
+            # The title is the first line, the body is the rest.
             open( my $article_fh, '<', $article_filepath )
                 or die "Can't open file '$article_filepath'";
             my $title = <$article_fh>;
             my $body = do { local $/; <$article_fh> };
 
-            # add content to index
+            # Add content to index.
             my $doc = Plucene::Document->new;
             $doc->add( Plucene::Document::Field->Text( title => $title ) );
             $doc->add(
@@ -276,7 +270,7 @@ sub build_index {
             );
             $writer->add_document($doc);
 
-            # bail if we've reached spec'd number of docs
+            # Bail if we've reached spec'd number of docs.
             $count++;
             last if ( $count >= $max );
             if ( $count % $increment == 0 and $count ) {
@@ -286,10 +280,10 @@ sub build_index {
         }
     }
 
-    # finish index
+    # Finish index.
     $writer->optimize;
 
-    # return elapsed seconds
+    # Return elapsed seconds.
     my $end  = gettimeofday();
     my $secs = $end - $start;
     return ( $count, $secs );
